@@ -19,10 +19,10 @@ module.exports = generators.Base.extend({
 
     this.argument('appName', { type: String, required: false });
     this.option('appName', { type: String, required: false });
-    /*this.option('appId', { type: String, required: false });
+    this.option('appId', { type: String, required: false });
     this.option('compass', { type: Boolean, required: false });
     this.option('starter', { type: String, required: false });
-    this.option('templates', { type: Array, required: false });
+    /*this.option('templates', { type: Array, required: false });
     this.option('plugins', { type: Object, required: false });*/
     this.option('auth', { type: Object, required: false });
     /*this.option('flurry', { type: Object, required: false });
@@ -32,7 +32,7 @@ module.exports = generators.Base.extend({
   },
 
   prompting: {
-    /*askForCompass: function askForCompass() {
+    askForCompass: function askForCompass() {
       var done = this.async();
 
       this.prompt([{
@@ -46,6 +46,9 @@ module.exports = generators.Base.extend({
         done();
       }.bind(this));
     },
+    askForRoutes: self.utils.routes.ask,
+    askForModels: self.utils.models.ask,
+    /*
     askForAnalytics: function askForAnalytics() {
       var done = this.async();
 
@@ -96,11 +99,12 @@ module.exports = generators.Base.extend({
 
       this.prompt(ionicUtils.auth.prompts, function (props) {
         console.log(props);        
-        this.auth = this.options.selected.auth = props.auth;
+        this.auth = this.options.selected.auth = props.providers;
+        console.log('AUTH:');
         console.log(this.auth);
         done();
       }.bind(this));
-    }/*,
+    },
     askForStarter: function askForStarter() {
       var done = this.async();
 
@@ -130,7 +134,7 @@ module.exports = generators.Base.extend({
         this.starter = this.options.selected.starter = _.find(ionicUtils.starters.templates, { name: props.starter });
         done();
       }.bind(this));
-    }*/
+    }
 
   },
 
@@ -183,7 +187,10 @@ module.exports = generators.Base.extend({
         done();
       }.bind(this));
     },
+    installModels: this.utils.models.install,
+    installRoutes: this.utils.routes.install,
     installAuthProvider: function installAuthProvider() {
+      console.log('installAuthProvider');
       console.log(this.auth);
       if (this.auth) {
         var done = this.async();
@@ -255,7 +262,7 @@ module.exports = generators.Base.extend({
         };
       }
     },
-
+  */
     installStarter: function installStarter() {
       console.log(chalk.yellow('Installing starter template. Please wait'));
       var done = this.async();
@@ -281,7 +288,7 @@ module.exports = generators.Base.extend({
       } else {
         this.remote(this.starter.user, this.starter.repo, 'master', callback, true);
       }
-    },*/
+    },
 
     readIndex: function readIndex() {
       this.indexFile = this.engine(this.read(path.join(this.starterCache, 'index.html')), this);
